API
---

The `mixin` module provides the main interface to this
module, and it is expected you will subclass it to provide
search functionality in your code.

```eval_rst
.. automodule:: printen.mixins
    :members:
```

The `utils` module provides various utility functions,
mostly useful to the mixin class but occasionally useful
elsewhere.

```eval_rst
.. automodule:: printen.utils
    :members:
```